@@ -24,7 +24,7 @@ class i18njs(BrowserView):
             else:
                 language = baselanguage
         _catalog = {}
-        for mo_path in td._catalogs[language]:
+        for mo_path in reversed(td._catalogs[language]):
             catalog = td._data[mo_path]._catalog
             if catalog is None:
                 td._data[mo_path].reload()
@@ -39,9 +39,6 @@ class i18njs(BrowserView):
         else:
             if language is None:
                 language = self.request['LANGUAGE']
-            tp = language.split("-")
-            if len(tp) > 1:
-                language = "%s_%s" % (tp[0],tp[1].upper())            
             catalog = self._gettext_catalog(domain, language)
 
         response = self.request.response
